#include <stdio.h>
#include <stdlib.h>
#include "structures.h"
#include "case.h"
#include "personnage.h"
#include "deplacements.h"

/*!
* \file personnage.c
* \brief Fichier contenant le code des fonctions liees aux personnages.
*/

Personnage* init_personnage(Personnage *perso, Classe *c, Case *casedepart){
    perso->classe=c;
    if(c!=NULL){
        perso->points_deplacement=c->points_deplacement_max;
        perso->PV=c->PV_max;
        perso->mana=c->mana_max;
    }
    perso->position=casedepart;
    marquer_occupee(casedepart);
    return perso;
}

Classe * getClasse(Personnage *p){
    return p->classe;
}

Case * getPosition(Personnage *p){
    return p->position;
}

int get_PV(Personnage *p){
    return p->PV;
}

int get_mana(Personnage *p){
    return p->mana;
}

int get_PD(Personnage *p){
    return p->points_deplacement;
}

/* Cette fonction ne fonctionne plus, il faut une fonction qui accede aux effets.
boolean est_paralyse(Personnage *p){
    return p->paralyse;
}
*/

int deplacer_personnage (Personnage *perso, Case *destination){ /*dplace un personnage d'une case  une autre. Ne vrifie pas si le dplacement est autoris, cela doit tre fait par la fonction qui l'appelle*/
    marquer_libre(getPosition(perso));
    perso->position=destination;
    marquer_occupee(getPosition(perso));
    if(getPosition(perso)==destination) return 0;
    return 1;
}

  /*!
 * \fn int estSurLaCase(Personnage * p, Case * c)
 * \brief La fonction teste si un Personnage est sur une Case.
 *
 * \param Le Personnage et la Case a tester.
 * \return 1 si le Personnage est sur la Case, 0 sinon.
 */
int estSurLaCase(Personnage * p, Case * c){
    return c==getPosition(p);
}

  /*!
 * \fn char * getNomPersonnage(Personnage * p)
 * \brief La fonction renvoie le nom d'un Personnage.
 *
 * \param Le Personnage a tester.
 * \return un pointeur vers la chaine de caractere representant le nom du Personnage, NULL si l'entree est NULL.
 */
char * getNomPersonnage(Personnage * p){
    if(p!=NULL){
        return p->nomPersonnage;
    }
    return NULL;
}


